==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/ComboBoxColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ColumnDescription } from "./ColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ComboBoxColumnDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ComboBoxColumnDescription, _super);
    function ComboBoxColumnDescription() {
        var _this = _super.call(this) || this;
        _this.fh = null;
        _this.fe = null;
        _this.fi = null;
        _this.fj = null;
        return _this;
    }
    ComboBoxColumnDescription.prototype.get_type = function () {
        return "ComboBoxColumn";
    };
    Object.defineProperty(ComboBoxColumnDescription.prototype, "dataSourceRef", {
        get: function () {
            return this.fh;
        },
        set: function (a) {
            this.fh = a;
            this.e("DataSourceRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComboBoxColumnDescription.prototype, "dataSource", {
        get: function () {
            return this.fe;
        },
        set: function (a) {
            this.fe = a;
            this.e("DataSource");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComboBoxColumnDescription.prototype, "textField", {
        get: function () {
            return this.fi;
        },
        set: function (a) {
            this.fi = a;
            this.e("TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComboBoxColumnDescription.prototype, "valueField", {
        get: function () {
            return this.fj;
        },
        set: function (a) {
            this.fj = a;
            this.e("ValueField");
        },
        enumerable: true,
        configurable: true
    });
    ComboBoxColumnDescription.$t = markType(ComboBoxColumnDescription, 'ComboBoxColumnDescription', ColumnDescription.$);
    ComboBoxColumnDescription.__canMarshalByValue1 = true;
    return ComboBoxColumnDescription;
}(ColumnDescription));
export { ComboBoxColumnDescription };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ComboBoxColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { DataGridColumnDescription } from "./DataGridColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ComboBoxColumnDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ComboBoxColumnDescription, _super);
    function ComboBoxColumnDescription() {
        var _this = _super.call(this) || this;
        _this.fh = null;
        _this.fe = null;
        _this.fi = null;
        _this.fj = null;
        return _this;
    }
    ComboBoxColumnDescription.prototype.get_type = function () {
        return "ComboBoxColumn";
    };
    Object.defineProperty(ComboBoxColumnDescription.prototype, "dataSourceRef", {
        get: function () {
            return this.fh;
        },
        set: function (a) {
            this.fh = a;
            this.e("DataSourceRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComboBoxColumnDescription.prototype, "dataSource", {
        get: function () {
            return this.fe;
        },
        set: function (a) {
            this.fe = a;
            this.e("DataSource");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComboBoxColumnDescription.prototype, "textField", {
        get: function () {
            return this.fi;
        },
        set: function (a) {
            this.fi = a;
            this.e("TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComboBoxColumnDescription.prototype, "valueField", {
        get: function () {
            return this.fj;
        },
        set: function (a) {
            this.fj = a;
            this.e("ValueField");
        },
        enumerable: true,
        configurable: true
    });
    ComboBoxColumnDescription.$t = markType(ComboBoxColumnDescription, 'ComboBoxColumnDescription', DataGridColumnDescription.$);
    ComboBoxColumnDescription.__canMarshalByValue1 = true;
    return ComboBoxColumnDescription;
}(DataGridColumnDescription));
export { ComboBoxColumnDescription };
